Learn R Programming

ogrdbstats (version 0.5.4)

make_haplo_grobs: Create haplotyping plots

Description

Create haplotyping plots

Usage

make_haplo_grobs(segment, haplo_details)

Value

named list containing the following elements:

a_allele_plotplot showing allele usage for each potential haplotyping gene
haplo_grobsdifferential plot of allele usage for each usable haplotyping gene

Arguments

segment

one of V, D, J

haplo_details

Data structure created by create_haplo_details

Examples

Run this code
haplo_grobs = make_haplo_grobs('V', example_rep$haplo_details)

Run the code above in your browser using DataLab