powered by
Create plots showing base usage at selected locations in sequences based on novel alleles
make_novel_base_grobs(inferred_seqs, input_sequences, segment, all_inferred)
named list containing the following elements:
named list of novel gene sequences
the input_sequences data frame
one of V, D, J
true if user has requested all alleles in reference set plotted - will suppress some warnings
base_grobs = make_novel_base_grobs( example_rep$inferred_seqs, example_rep$input_sequences, 'V', FALSE )
Run the code above in your browser using DataLab